<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/ecrire_?lang_cible=ro
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) {
	return;
}

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// A
	'activer_plugin' => 'Activaţi plugin-ul',
	'affichage' => 'Afişaj',
	'aide_non_disponible' => 'Această parte din Help înca nu e disponibilă în această limbă',
	'auteur' => 'Autor :',
	'avis_acces_interdit' => 'Accesul interzis.',
	'avis_article_modifie' => 'Atenţie, @nom_auteur_modif@ a lucrat la acest articol în urmă cu @date_diff@ minute',
	'avis_aucun_resultat' => 'Fără rezultat.',
	'avis_base_inaccessible' => 'Conexiunea la baza de date @base@ nu e posibilă.',
	'avis_chemin_invalide_1' => 'Calea pe care aţi ales-o',
	'avis_chemin_invalide_2' => ' nu pare a fi valabilă. Vă rugăm să reveniţi la pagina anterioară pentru a verifica informaţiile furnizate.',
	'avis_connexion_echec_1' => 'Conexiunea la baza de date a eşuat.',
	'avis_connexion_echec_2' => 'Reveniţi la pagina anterioară şi verificaţi datele completate.',
	'avis_connexion_echec_3' => '<b>Nota Bene</b> Pe multe servere, trebuie să <b>cereţi</b> activarea accesului la baza de date inainte de a o putea utiliza. Dacă nu reuşiţi să vă conectaţi, verificaţi că aţi efectuat această operaţie.',
	'avis_connexion_ldap_echec_1' => 'Conexiunea la serverul LDAP a eşuat.',
	'avis_connexion_ldap_echec_2' => 'Reveniţi la pagina anterioară şi verificaţi datele completate.',
	'avis_connexion_ldap_echec_3' => 'Ca alternativă, importaţi utilizatorii fără să folosiţi suportul LDAP.',
	'avis_deplacement_rubrique' => 'Atenţie! În această rubrică se găsesc @contient_breves@ ştiri@scb@: dacă o deplasaţi, bifaţi această casetă de confirmare.',
	'avis_erreur_connexion_mysql' => 'Eroare de conexiune SQL',
	'avis_espace_interdit' => '<b>Spaţiu interzis</b> <div>SPIP este déjà instalat</div>.',
	'avis_lecture_noms_bases_1' => 'Programul de instalare nu a putut citi numele bazelor de date instalate.',
	'avis_lecture_noms_bases_2' => 'Fie nici o bază de date nu este disponibilă, fie funcţia de listare a bazelor de date a fost dezactivată pentru motive de securitate (cei mai mulţi furnizori procedează astfel).',
	'avis_lecture_noms_bases_3' => 'Cu cea de-a doua alternativă, este probabil că o bază de date cu un nume la fel ca login-ul dumneavoastră este disponibilă :',
	'avis_non_acces_page' => 'Nu aveţi acces la această pagină.',
	'avis_operation_echec' => 'Operaţia a eşuat.',
	'avis_operation_impossible' => 'Operaţie imposibilă',
	'avis_suppression_base' => 'ATENŢIE, suprimarea datelor este ireversibilă',

	// B
	'bouton_acces_ldap' => 'Adăugaţi accesul la LDAP',
	'bouton_ajouter' => 'Adăugaţi',
	'bouton_annuler' => 'Anulaţi',
	'bouton_cache_activer' => 'Reativar o cache',
	'bouton_cache_desactiver' => 'Desativar temporariamente o cache',
	'bouton_demande_publication' => 'Cereţi publicarea articolului',
	'bouton_desactive_tout' => 'Dezactivaţi totul',
	'bouton_desinstaller' => 'Dezinstalaţi',
	'bouton_effacer_tout' => 'Ştergeţi TOTUL',
	'bouton_envoyer_message' => 'Mesajul definitiv: trimiteţi',
	'bouton_fermer' => 'Închideţi',
	'bouton_mettre_a_jour_base' => 'Aduceţi la zi baza de date',
	'bouton_modifier' => 'Modificaţi',
	'bouton_radio_afficher' => 'Afişaţi',
	'bouton_radio_apparaitre_liste_redacteurs_connectes' => 'Apariţie în lista redactorilor conectaţi',
	'bouton_radio_envoi_annonces_adresse' => 'Trimiteţi anunţurile la adresa :',
	'bouton_radio_envoi_liste_nouveautes' => 'Trimiteţi lista de noutăţi',
	'bouton_radio_non_apparaitre_liste_redacteurs_connectes' => 'Nu apăreţi în lista redactorilor',
	'bouton_radio_non_envoi_annonces_editoriales' => 'Nu trimiteţi anunţuri editoriale',
	'bouton_redirection' => 'REDIRIJARE',
	'bouton_relancer_installation' => 'Relansaţi instalarea',
	'bouton_suivant' => 'Următorul',
	'bouton_tenter_recuperation' => 'Încercaţi o reparare',
	'bouton_test_proxy' => 'Încercaţi proxy-ul',
	'bouton_vider_cache' => 'Goliţi memoria tampon',

	// C
	'cache_modifiable_webmestre' => 'Acest parametru est modificabil de către webmaster-ul acestui site.',
	'calendrier_synchro' => 'Dacă folosiţi un soft de agendă compatibil <b>iCal</b>, puteţi să-l sincronizaţi cu informaţiile de pe site.',
	'config_activer_champs' => 'Activaţi câmpurile următoare',
	'config_choix_base_sup' => 'indicaţi o bază pe acest server',
	'config_erreur_base_sup' => 'SPIP nu are acces la lista bazelor de date disponibile',
	'config_info_base_sup' => 'Dacă aveţi alte baze de date pe care doriţi să le interogaţi cu ajutorul SPIP, prin server-ul său SQL sau un altul, formularul de mai jos vă permite să le declaraţi. Dacă veţi lăsa anumite câmpuri goale, identificarea utilizată pentru baza de date principală vor fi folosiţi în mod automat.',
	'config_info_base_sup_disponibles' => 'Baze de date suplimentare care pot fi deja interogabile:',
	'config_info_enregistree' => 'Noua configuraţie a fost înregistrată',
	'config_info_logos' => 'Fiecare element al site-ului poate avea atât un logo, cât şi un « logo de survol »',
	'config_info_logos_utiliser' => 'Utilizaţi logo-urile',
	'config_info_logos_utiliser_non' => 'Nu utilizaţi logo-urile',
	'config_info_logos_utiliser_survol' => 'Utilizaţi logo-urile de survol',
	'config_info_logos_utiliser_survol_non' => 'Nu utilizaţi logo-urile de survol',
	'config_info_redirection' => 'Prin activarea acestei opţiuni, veţi putea crea articole virtuale, simple referinţe către articole publicate pe alte site-uri sau în afara sistemului SPIP.',
	'config_redirection' => 'Articole virtuale',
	'config_titre_base_sup' => 'Declararea unei baze de date suplimentare',
	'config_titre_base_sup_choix' => 'Alegeţi o bază de date suplimentară',
	'connexion_ldap' => 'Conexiune :',

	// D
	'date_mot_heures' => 'ore',

	// E
	'ecran_securite' => ' + ecran de securitate @version@',
	'email' => 'email',
	'email_2' => 'email :',
	'en_savoir_plus' => 'Vreau să ştiu mai multe',
	'entree_adresse_annuaire' => 'Adresa anuarului',
	'entree_adresse_email' => 'Adresa dumneavoastră de email',
	'entree_base_donnee_1' => 'Adresa bazei de date',
	'entree_base_donnee_2' => '(Deseori această adresă corespunde cu cea a site-ului dumneavoastră, câteodata ea corespunde menţiunii «localhost», iar câteodată este lăsată complet goală.)',
	'entree_biographie' => 'O scurta biografie în câteva cuvinte.',
	'entree_chemin_acces' => '<b>Introduceţi</b> calea de acces :',
	'entree_cle_pgp' => 'Cheia dumneavoastră PGP',
	'entree_contenu_rubrique' => '(Conţinutul rubricii în câteva cuvinte.)',
	'entree_identifiants_connexion' => 'Identificatorii dumneavoastră de acces...',
	'entree_informations_connexion_ldap' => 'Vă rugăm să furnizaţi în acest formular informaţiile de conectare la anuarul LDAP.
 Aceste informaţii ar trebui să poată fi furnizate de către administratorul dumneavoastră de sistem sau reţea.',
	'entree_infos_perso' => 'Cine sunteţi dumneavoastra ?',
	'entree_interieur_rubrique' => 'În interiorul rubricii :',
	'entree_liens_sites' => '<b>Legătură hipertext</b> (referinţă, site de vizitat...)',
	'entree_login' => 'Login-ul dumneavoastră',
	'entree_login_connexion_1' => 'Login-ul de conectare',
	'entree_login_connexion_2' => '(Corespunde câteodată cu login-ul de acces FTP; uneori este lăsat gol)',
	'entree_mot_passe' => 'Parola dumneavoatră',
	'entree_mot_passe_1' => 'Parola conexiunii',
	'entree_mot_passe_2' => '(Corespunde câteodată cu parola de acces FTP; uneori este vidă)',
	'entree_nom_fichier' => 'Vă rugăm să introduceţi numele fişierului @texte_compresse@:',
	'entree_nom_pseudo' => 'Numele sau pseudonimul dumneavoastră',
	'entree_nom_pseudo_1' => '(Numele sau pseudonimul dumneavoastră)',
	'entree_nom_site' => 'Numele site-ului dumneavoastră',
	'entree_nouveau_passe' => 'Noua parolă',
	'entree_passe_ldap' => 'Parola',
	'entree_port_annuaire' => 'Numărul de port al anuarului',
	'entree_signature' => 'Semnatură',
	'entree_titre_obligatoire' => '<b>Titlu</b> [Obligatoriu]<br />',
	'entree_url' => 'Adresa (URL) site-ului dumneavoastră',
	'erreur_connect_deja_existant' => 'Un server cu acest nume există deja',
	'erreur_nom_connect_incorrect' => 'Acest nume de server nu este autorizat',
	'erreur_plugin_desinstalation_echouee' => 'Dezinstalarea plugin-ului a eşuat. Puteţi totuşi să îl dezactivaţi.', # MODIF
	'erreur_plugin_fichier_absent' => 'Fişier lipsă',
	'erreur_plugin_fichier_def_absent' => 'Fişier de definiţii lipsă',
	'erreur_plugin_nom_fonction_interdit' => 'Nume de funcţie interzis',
	'erreur_plugin_nom_manquant' => 'Nume plugin lipsă',
	'erreur_plugin_prefix_manquant' => 'Spaţiul de nume a plugin-ului nedefinit',
	'erreur_plugin_tag_plugin_absent' => '&lt;plugin&gt; lipsă în fişierul de definiţii',
	'erreur_plugin_version_manquant' => 'Versiunea plugin-ului lipsă',

	// H
	'htaccess_inoperant' => 'htaccess nu funcţionează',

	// I
	'ical_info1' => 'Această pagină prezintă mai multe metode pentru a rămâne în contact cu activitatea de pe acest site.',
	'ical_info2' => 'Pentru mai multe detalii asupra acestor tehnici, nu ezitaţi să consultaţi <a href="@spipnet@">documentaţia SPIP</a>.',
	'ical_info_calendrier' => 'Două calendare vă sunt la dispoziţie: Primul este un plan al site-ului care anunţă toate articolele publicate. Al doilea conţine atât anunţurile editoriale cât şi ultimele mesaje private : acesta vă este rezervat graţie unei chei personale pe care o puteţi modifica oricând prin simpla schimbare a parolei dumneavoastră.  ',
	'ical_methode_http' => 'Descărcare',
	'ical_methode_webcal' => 'Sincronizare (webcal://)', # MODIF
	'ical_texte_js' => 'O linie de cod javascript vă permite să afişaţi de o manieră simplă, pe orice site care vă aparţine, articolele recente publicate pe aceste site.',
	'ical_texte_prive' => 'Acest calendar, pentru o folosire strict personală, vă informează despre activitatea editorială a acestui site (sarcini şi întâlniri personale, articole şi ştiri propuse spre publicare...)',
	'ical_texte_public' => 'Acest calendar vă permite să urmăriţi activitatea publică a acestui site (articole şi ştiri publicate).',
	'ical_texte_rss' => 'Puteţi sindicaliza noutăţile acestui site în orice program de citire fişiere în format XML/RSS (Rich Site Summary). Acest format este acelaşi care îi permite lui SPIP să citească noutăţile publicate pe alte site-uri care folosesc un protocol de schimb compatibil (site-uri sindicalizate).',
	'ical_titre_js' => 'Javascript',
	'ical_titre_mailing' => 'Lista de email-uri',
	'ical_titre_rss' => 'Fişiere de sindicalizare',
	'icone_accueil' => 'Prima pagină',
	'icone_activer_cookie' => 'Activaţi cookie-ul de corespondenţă',
	'icone_activite' => 'Activitate',
	'icone_admin_plugin' => 'Gestiune plugin-uri',
	'icone_administration' => 'Mentenanţă',
	'icone_afficher_auteurs' => 'Afişaţi autorii',
	'icone_afficher_visiteurs' => 'Afişaţi vizitatorii',
	'icone_arret_discussion' => 'Nu mai participaţi la această dicuţie',
	'icone_calendrier' => 'Calendar',
	'icone_configuration' => 'Configurare',
	'icone_creer_auteur' => 'Creaţi un nou autor şi atribuiţi-i articolul.',
	'icone_creer_mot_cle' => 'Creaţi un nou cuvânt-cheie şi legaţi-l de acest articol.',
	'icone_creer_rubrique_2' => 'Creaţi o nouă rubrică',
	'icone_edition' => 'Editare',
	'icone_ma_langue' => 'Limba mea',
	'icone_mes_infos' => 'Informaţiile mele',
	'icone_mes_preferences' => 'Preferinţele mele',
	'icone_modifier_article' => 'Modificaţi acest articol',
	'icone_modifier_rubrique' => 'Modificaţi această rubrică',
	'icone_publication' => 'Publicare',
	'icone_relancer_signataire' => 'Relansaţi semnatarul',
	'icone_retour' => 'Înapoi',
	'icone_retour_article' => 'Înapoi la articol',
	'icone_squelette' => 'Schelete',
	'icone_suivi_publication' => 'Urmărirea publicării',
	'icone_supprimer_cookie' => 'Ştergeţi cookie-ul de corespondenţă',
	'icone_supprimer_rubrique' => 'Ştergeţi această rubrică',
	'icone_supprimer_signature' => 'Ştergeţi această semnătură',
	'icone_valider_signature' => 'Validaţi această semnătură',
	'image_administrer_rubrique' => 'Puteţi administra această rubrică',
	'impossible_modifier_login_auteur' => 'Impossible de modifier le login.', # MODIF
	'impossible_modifier_pass_auteur' => 'Impossible de modifier le mot de passe.', # MODIF
	'info_1_article' => '1 articol',
	'info_1_auteur' => '1 autor',
	'info_1_message' => '1 mesaj',
	'info_1_mot_cle' => '1 cuvânt-cheie',
	'info_1_rubrique' => '1 rubrică',
	'info_1_visiteur' => '1 vizitator',
	'info_activer_cookie' => 'Puteţi să activaţi un <b>cookie de corespondenţă</b>, ceea ce vă va
 permite să treceţi cu uşurinţă de la site-ul public la site-ul privat.',
	'info_admin_etre_webmestre' => 'Daţi-mi drepturi de webmaster',
	'info_admin_je_suis_webmestre' => 'Sunt <b>webmaster</b>',
	'info_admin_statuer_webmestre' => 'Daţi acestui administrator drepturi de webmaster',
	'info_admin_webmestre' => 'Acest administrator este <b>webmaster</b>',
	'info_administrateur' => 'Administrator',
	'info_administrateur_1' => 'Administrator',
	'info_administrateur_2' => 'al site-ului (<i>utilizaţi cu prudenţă</i>)',
	'info_administrateur_site_01' => 'Dacă sunteţi administrator al site-ului, vă rugăm',
	'info_administrateur_site_02' => ' să faceţi click pe această legatură',
	'info_administrateurs' => 'Administratori',
	'info_administrer_rubrique' => 'Puteţi administra această rubrică',
	'info_adresse' => 'la adresa :',
	'info_adresse_url' => 'Adresa (URL) a site-ului public',
	'info_aide_en_ligne' => 'Ajutor SPIP în linie',
	'info_ajout_image' => 'Când adăugaţi imagini ca documente ataşate unui articol, SPIP poate crea pentru dvs. viniéte ale imaginilor introduse. Aceasta permite de exemplu crearea automată a unei galerii sau a unui portofoliu.',
	'info_ajouter_rubrique' => 'Adăugaţi o altă rubrică de administrat :',
	'info_annonce_nouveautes' => 'Anunţul noutăţilor',
	'info_article' => 'articol',
	'info_article_2' => 'articole',
	'info_article_a_paraitre' => 'Articolele post-datate care urmează să fie publicate',
	'info_articles_02' => 'articole',
	'info_articles_2' => 'Articole',
	'info_articles_auteur' => 'Articole de acelaşi autor',
	'info_articles_miens' => 'Articolele mele',
	'info_articles_tous' => 'Toate articolele',
	'info_articles_trouves' => 'Articole găsite',
	'info_attente_validation' => 'Articolele dumneavoastră în curs de validare',
	'info_aucun_article' => 'Nici un articol',
	'info_aucun_auteur' => 'Nici un autor',
	'info_aucun_message' => 'Nici un mesaj',
	'info_aucun_rubrique' => 'Nici o rubrică',
	'info_aujourdhui' => 'astăzi :',
	'info_auteurs' => 'Autorii',
	'info_auteurs_par_tri' => 'Autori @partri@',
	'info_auteurs_trouves' => 'Autori găsiţi',
	'info_authentification_externe' => 'Autentificare externă',
	'info_avertissement' => 'Avertisment',
	'info_barre_outils' => 'cu toolbar-ul său ?',
	'info_base_installee' => 'Structura bazei dumneavoastră de date a fost instalată.',
	'info_cache_desactive' => 'Cache temporariamente desativado.',
	'info_chapeau' => 'Introducere',
	'info_chapeau_2' => 'Introducere :',
	'info_chemin_acces_1' => 'Opţiuni: <b>Calea de acces în anuar</b>',
	'info_chemin_acces_2' => 'Trebuie ca acum să configuraţi calea de acces la informaţiile din anuar. Această informaţie este indispensabilă pentru lectura profilului utilizatorilor memoraţi în anuar.',
	'info_chemin_acces_annuaire' => 'Opţiuni: <b>Calea de acces în anuar</b>',
	'info_choix_base' => 'Cea de-a treia etapă :',
	'info_classement_1' => 'pe @liste@',
	'info_classement_2' => 'pe @liste@',
	'info_code_acces' => 'Nu uitaţi propriile dumeavoastră coduri de acces !',
	'info_config_suivi' => 'Dacă această adresă corespunde unei liste de email-uri, puteţi indica mai jos adresa la care participanţii la site se pot înscrie. Această adresă poate fi un URL (de exemplu adresa paginii de însriere la listă pe Web) sau o adresă de email dotată cu un subiect specific (de exemplu: <tt>@adresse_suivi@?subject=subscribe</tt>):',
	'info_config_suivi_explication' => 'Puteţi să vă abonaţi la lista de email-uri a acestui site. Veţi primi ca urmare anunţuri de ştiri sau articole propuse spre publicare.',
	'info_confirmer_passe' => 'Confirmaţi această nouă parolă :',
	'info_conflit_edition_avis_non_sauvegarde' => 'Atenţie, câmpurile următoare au fost modificate în altă parte. Modificările dumneavoastră asupra acestor câmpuri nu au fost, aşadar, înregistrate.',
	'info_conflit_edition_differences' => 'Diferenţe :',
	'info_conflit_edition_version_enregistree' => 'Versiunea înregistrată :',
	'info_conflit_edition_votre_version' => 'Versiunea dumneavoastră :',
	'info_connexion_base' => 'Încercarea conexiunii la baza de date',
	'info_connexion_base_donnee' => 'Conexiunea la baza dumneavoastră de date',
	'info_connexion_ldap_ok' => 'Conexiunea LDAP a reuşit.</b><p>Puteţi trece la etapa următoare.<p/>', # MODIF
	'info_connexion_mysql' => 'Conexiunea dumneavoastră SQL',
	'info_connexion_ok' => 'Conexiunea a reuşit.',
	'info_contact' => 'Contact',
	'info_contenu_articles' => 'Conţinutul articolelor',
	'info_creation_paragraphe' => '(Pentru a crea paragrafe, lăsaţi pur şi simplu liniile goale.)', # MODIF
	'info_creation_rubrique' => 'Înainte de a putea scrie articole,<br /> trebuie să creaţi cel puţin o rubrică.<br />',
	'info_creation_tables' => 'Crearea tabelelor bazei de date',
	'info_creer_base' => '<b>Creaţi</b> o nouă baze de date :',
	'info_dans_rubrique' => 'În rubrica :',
	'info_date_publication_anterieure' => 'Data redactării anterioare :',
	'info_date_referencement' => 'DATA DE REFERENŢIERE A ACESTUI SITE :',
	'info_derniere_etape' => 'Gata !',
	'info_descriptif' => 'Descriere :',
	'info_desinstaller_plugin' => 'şterge datele şi dezactivează plugin-ul',
	'info_discussion_cours' => 'Discuţii în desfăşurare',
	'info_ecrire_article' => 'Înainte de a putea scrie articole, trebuie să creaţi cel puţin o rubrică.<br />',
	'info_email_envoi' => 'Adresa email de trimitere (opţional)',
	'info_email_envoi_txt' => 'Indicaţi aici adresa care va fi folosită pentru a trimite email-uri (dacă nu furnizaţi o adresă, este adresa destinatarului care va fi folosită în mod implicit) :',
	'info_email_webmestre' => 'Adresa de email a webmaster-ului (opţional)', # MODIF
	'info_envoi_email_automatique' => 'Trimitere automată de email-uri',
	'info_envoyer_maintenant' => 'Trimiteţi acum',
	'info_etape_suivante' => 'Treceţi la etapa următoare',
	'info_etape_suivante_1' => 'Nu puteţi trece la etapa următoare.',
	'info_etape_suivante_2' => 'Puteţi trece la etapa următoare.',
	'info_exportation_base' => 'exportul bazei de date către @archive@',
	'info_facilite_suivi_activite' => 'Pentru a uşura urmărirea activităţii editoriale a site-ului, SPIP poate trimite prin email cererile de publicare şi de validare a articolelor. De exemplu, destinatarul poate fi o listă de distribuţie a redacţiei.', # MODIF
	'info_fichiers_authent' => 'Fişiere de autentificare « .htpasswd »',
	'info_forums_abo_invites' => 'Site-ul dumneavoastră are forum-uri cu abonament ; vizitatorii sunt, aşadar, invitaţi să se înregistreze pe site-ul public.',
	'info_gauche_admin_tech' => '<b>Această pagină este accesibilă doar responsabililor acestui site</b><br /> Ea dă acces la diverse funcţii de întreţinere tehnică. Unele dintre aceste funcţii cer un proces de autentificare specific, de exemplu să aveţi un acces FTP la site-ul Web.', # MODIF
	'info_gauche_admin_vider' => '<b>Această pagină este accesibilă doar responsabililor acestui site</b><br /> Ea dă acces la diverse funcţii de întreţinere tehnică. Unele dintre aceste funcţii cer un proces de autentificare specific, de exemplu să aveţi un acces FTP la site-ul Web.', # MODIF
	'info_gauche_auteurs' => 'Găsiţi aici toţi autorii acestui site.
 Starea lor este indicată prin codul de culori al iconiţei asociate (administrator = verde; redactor = galben).',
	'info_gauche_auteurs_exterieurs' => 'Autorii existenţi, fără acces la site, sunt indicaţi cu ajutorul unei iconiţe albastre ;
  iar autorii şterşi - printr-o iconiţă ce simbolizează un coş de gunoi.', # MODIF
	'info_gauche_messagerie' => 'Mesageria vă permite să schimbaţi mesaje între redactori, să conservaţi ciorne (pentru folosul dumneavoastră personal) sau pentru a afişa anunţuri pe pagina de gardă a spaţiului privat (dacă sunteţi administrator).',
	'info_gauche_statistiques_referers' => 'Această pagină prezintă lista <i>referers</i>, adică a site-urilor care conţin legături către acest site, doar pentru ieri şi astăzi ; această listă este re-iniţializată la fiecare 24 de ore.',
	'info_gauche_visiteurs_enregistres' => 'Veţi găsi aici vizitatorii înregistraţi
în spaţiul public al site-ului (forum-urile pe bază de abonament).',
	'info_generation_miniatures_images' => 'Generarea de miniaturi ale imaginilor',
	'info_hebergeur_desactiver_envoi_email' => 'Anumiţi furnizori de servicii de hosting dezactivează trimiterea automată de
  email-uri de pe server-ele lor. În acest caz, funcţiile următoare
  din SPIP nu sunt disponibile.',
	'info_hier' => 'ieri :',
	'info_identification_publique' => 'Identitatea dumneavoastră publică...',
	'info_image_process' => 'Vă rugăm să selecţionaţi cea mai bună metodă de generare a viniételor făcând click pe imaginea corespunzătoare.',
	'info_image_process2' => '<b>Nota Bene</b> <i> Dacă nici o imagine nu este afişată, înseamnă ca server-ul care găzduieşte site-ul dumneavoastră nu a fost configurat să folosească unelte de acest tip. Dacă doriţi să folosiţi aceste funcţii, vă rugăm să-l contactaţi pe responsabilul tehnic şi să îi cereţi instalarea extensiilor «GD» sau «Imagick».</i>', # MODIF
	'info_images_auto' => 'Imagini calculate automat',
	'info_informations_personnelles' => 'Informaţii personale',
	'info_inscription_automatique' => 'Înscrierea automatică a noi redactori',
	'info_jeu_caractere' => 'Setul de caractere al site-ului',
	'info_jours' => 'zile',
	'info_laisser_champs_vides' => ' lăsaţi aceste câmpuri goale)',
	'info_langues' => 'Limbile site-ului',
	'info_ldap_ok' => 'Autentificarea LDAP a fost instalată.',
	'info_lien_hypertexte' => 'Legătură hipertext :',
	'info_liste_redacteurs_connectes' => 'Lista redactorilor conectaţi',
	'info_login_existant' => 'Acest login există déjà.',
	'info_login_trop_court' => 'Login prea scurt.',
	'info_logos' => 'Logo-urile',
	'info_maximum' => 'maxim :',
	'info_meme_rubrique' => 'În aceeaşi rubrică',
	'info_message_en_redaction' => 'Mesajele dumneavoastră în curs de redactare',
	'info_message_technique' => 'Mesaj tehnic :',
	'info_messagerie_interne' => 'Mesagerie internă',
	'info_mise_a_niveau_base' => 'aducere la zi a bazei dumneavoastră de date SQL',
	'info_mise_a_niveau_base_2' => '{{Atenţie!}} Aţi instalat o versiune
  de fişiere SPIP {anterioară} celei care se găsea înainte pe acest site:
  baza dumneavoastră de date riscă să fie
  pierdută şi site-ul dumneavoastră nu va mai funcţiona.
{{Reinstalaţi fişierele originale SPIP.}}',
	'info_modifier_auteur' => 'Modificaţi autorul :',
	'info_modifier_rubrique' => 'Modificaţi rubrica :',
	'info_modifier_titre' => 'Modificaţi : @titre@',
	'info_mon_site_spip' => 'Site-ul meu SPIP',
	'info_moyenne' => 'medie :',
	'info_multi_cet_article' => 'Limba acestui articol :',
	'info_multi_langues_choisies' => 'Vă rugăm să selecţionaţi aici limbile aflate la dispoziţia redactorilor site-ului dumneavoastră.
  Limbile deja folosite în cadrul site-ului (afişate primele) nu pot fi dezactivate.',
	'info_multi_secteurs' => '... doar pentru rubricile situate sub rădăcină ?',
	'info_nom' => 'Nume',
	'info_nom_destinataire' => 'Numele destinatarului',
	'info_nom_site' => 'Numele site-ului dumneavoastră',
	'info_nombre_articles' => '@nb_articles@ articole,',
	'info_nombre_rubriques' => '@nb_rubriques@ rubrici,',
	'info_nombre_sites' => '@nb_sites@ site-uri,',
	'info_non_deplacer' => 'Nu deplasaţi...',
	'info_non_envoi_annonce_dernieres_nouveautes' => 'SPIP poate trimite regulat anunţuri despre articolele şi ştirile publicate recent.',
	'info_non_envoi_liste_nouveautes' => 'Nu trimiteţi la lista noutăţilor',
	'info_non_modifiable' => 'nu poate fi modificat(ă)',
	'info_non_suppression_mot_cle' => 'nu doresc să şterg acest cuvânt-cheie.',
	'info_notes' => 'Note',
	'info_nouvel_article' => 'Articol nou',
	'info_nouvelle_traduction' => 'Traducere nouă :',
	'info_numero_article' => 'ARTICOL NUMĂRUL :',
	'info_obligatoire_02' => '[Obligatorie]', # MODIF
	'info_option_accepter_visiteurs' => 'Acceptaţi înscrierea vizitatorilor site-ului public',
	'info_option_ne_pas_accepter_visiteurs' => 'Refuzaţi înscrierea vizitatorilor',
	'info_options_avancees' => 'OPŢIUNI AVANSATE',
	'info_ou' => 'sau...',
	'info_page_interdite' => 'Pagină interzisă',
	'info_par_nom' => 'după nume',
	'info_par_nombre_article' => 'după numărul de articole',
	'info_par_statut' => 'după statut',
	'info_par_tri' => '’(după @tri@)’',
	'info_passe_trop_court' => 'Parolă prea scurtă.',
	'info_passes_identiques' => 'Cele două parole nu sunt identice.',
	'info_plus_cinq_car' => 'mai mult de 5 caractere',
	'info_plus_cinq_car_2' => '(Mai mult de 5 caractere)',
	'info_plus_trois_car' => '(Mai mult de 3 caractere)',
	'info_popularite' => 'popularitate : @popularite@ ; vizite : @visites@',
	'info_post_scriptum' => 'Post-Scriptum',
	'info_post_scriptum_2' => 'Post-scriptum :',
	'info_pour' => 'pentru',
	'info_preview_texte' => 'Este posibilă previzualizarea site-ului ca şi cum toate articolele şi ştirile (care au cel puţin starea « propus ») ar fi fost deja publicate. Această posibilitate trebuie să fie disponibilă doar pentru administratori, la toţi redactorii, sau nimănui ?', # MODIF
	'info_procedez_par_etape' => 'procedaţi etapă cu etapă',
	'info_procedure_maj_version' => 'procedura de aducere la zi trebuie lansată pentru a adapta
 baza de date la noua versiune SPIP.',
	'info_proxy_ok' => 'Test de proxy reuşit.',
	'info_ps' => 'P.S.',
	'info_publier' => 'publicaţi',
	'info_publies' => 'Articolele dumneavoatră publicate în direct',
	'info_question_accepter_visiteurs' => 'Dacă scheletele site-ului dumneavoastră prevăd înregistrarea vizitatorilor fără acces la spaţiul privat, vă rugăm să activaţi opţiunea de mai jos :',
	'info_question_inscription_nouveaux_redacteurs' => 'Acceptaţi înscrierea de noi redactori
  în partea publică a site-ului ? Dacă acceptaţi, vizitatorii vor putea să se înscrie
  cu ajutorul unui formular automatizat şi vor putea avea acces la spaţiul privat pentru a propune
  propriile lor articole. <blockquote><i>Ca urmare a procesului de înscriere,
  utilizatorii vor primi un email automatic
  care le va furniza codurile de acces la site-ul privat. Anumiţi
  furnizori de hosting dezactivează trimiterea de email-uri de pe
  server-ele lor : în acest caz înscrierea automatică este
  imposibilă.', # MODIF
	'info_racine_site' => 'Rădăcina site-ului',
	'info_recharger_page' => 'Vă rugăm să reîncărcaţi această pagină în câteva momente.',
	'info_recherche_auteur_zero' => 'Nici un rezultat pentru « @cherche_auteur@ ».',
	'info_recommencer' => 'Vă rugăm să reîncepeţi.',
	'info_redacteur_1' => 'Redactor',
	'info_redacteur_2' => ' care are dreptul de acces la spaţiul privat (<i>recomandat</i>)',
	'info_redacteurs' => 'Redactori',
	'info_redaction_en_cours' => 'ÎN REDACTARE',
	'info_redirection' => 'Redirijare',
	'info_refuses' => 'Articolele dumneavoastră refuzate',
	'info_reglage_ldap' => 'Opţiuni : <b>Reglajele importului LDAP</b>',
	'info_renvoi_article' => '<b>Redirijare.</b> Acest articol trimite la pagina:',
	'info_reserve_admin' => 'Doar administratorii pot modifica această adresă.',
	'info_restreindre_rubrique' => 'Restrângeţi gestiunea la rubrica:',
	'info_resultat_recherche' => 'Rezultatele căutării :',
	'info_rubriques' => 'Rubrici',
	'info_rubriques_02' => 'rubrici',
	'info_rubriques_trouvees' => 'Rubrici găsite',
	'info_sans_titre' => 'Fără titlu',
	'info_selection_chemin_acces' => '<b>Selecţionaţi</b> aici calea de acces în anuar :',
	'info_signatures' => 'semnături',
	'info_site' => 'Site',
	'info_site_2' => 'site :',
	'info_site_min' => 'site',
	'info_site_reference_2' => 'Site referenţiat',
	'info_sites' => 'site-uri',
	'info_sites_lies_mot' => 'Site-urile referenţiate legate la acest cuvânt-cheie',
	'info_sites_proxy' => 'Utilizaţi un proxy',
	'info_sites_trouves' => 'Site-uri găsite',
	'info_sous_titre' => 'Subtitlu :',
	'info_statut_administrateur' => 'Administrator',
	'info_statut_auteur' => 'Starea acestui autor :',
	'info_statut_auteur_a_confirmer' => 'Inscriere de confirmat',
	'info_statut_auteur_autre' => 'Alt statut :',
	'info_statut_redacteur' => 'Redactor',
	'info_statut_utilisateurs_1' => 'Starea implicită a utilizatorilor importaţi',
	'info_statut_utilisateurs_2' => 'Alegeţi starea implicită care este atribuită persoanelor care sunt prezente în anuarul LDAP atunci când se vor conecta pentru prima dată. Veţi putea modifica mai târziu această valoare caz după caz, pentru fiecare autor.',
	'info_suivi_activite' => 'Urmărirea activităţii editoriale',
	'info_surtitre' => 'Supratitlu :',
	'info_syndication_integrale_1' => 'Site-ul dumneavoastră propune fişiere de sindicalizare (vedeţi « <a href="@url@">@titre@</a> »).',
	'info_syndication_integrale_2' => 'Doriţi să transmiteţi articolele în totalitatea lor, sau doar să difuzaţi un rezumat de câteva sute de simboluri ?',
	'info_table_prefix' => 'Puteţi modifica prefixul numelor tabelelor din baza de date (această etapă este indispensabilă atunci când doriţi să instalaţi mai multe site-uri în aceeaşi bază de date). Acest prefix trebuie să fie scris cu litere mici, fără accente sau diacritice şi fără spaţii.',
	'info_taille_maximale_images' => 'SPIP va testa mărimea maximă a imaginilor pe care le poate procesa (în milioane de de pixeli).
Imaginile cu dimensiuni mai mari nu vor fi reduse.',
	'info_taille_maximale_vignette' => 'Talia maximală a viniételor generate de către sistem :',
	'info_terminer_installation' => 'Acum puteţi să terminaţi procedura standard de instalare.',
	'info_texte' => 'Text',
	'info_texte_explicatif' => 'Text explicativ',
	'info_texte_long' => '(textul este lung : ca urmare, va apare în mai multe părţi care vor fi relipite după validare.)',
	'info_texte_message' => 'Textul mesajului dumneavoastră :', # MODIF
	'info_texte_message_02' => 'Textul mesajului',
	'info_titre' => 'Titlu :',
	'info_total' => 'total :',
	'info_tous_articles_en_redaction' => 'Toate articolele în curs de redactare',
	'info_tous_articles_presents' => 'Toate articolele publicate în această rubrică',
	'info_tous_les' => 'toate :',
	'info_tout_site' => 'Tot site-ul',
	'info_tout_site2' => 'Articolul nu a fost tradus în această limbă.',
	'info_tout_site3' => 'Articolul a fost tradus în această limbă, dar există modificări ale articolului de referinţă. Traducerea trebuie adusă la zi.',
	'info_tout_site4' => 'Articolul a fost tradus în această limbă şi traducerea este la zi.',
	'info_tout_site5' => 'Articol original.',
	'info_tout_site6' => '<b>Atenţie :</b> doar articolele originale sunt afişate.
Traducerile sunt asociate originalului,
cu o culoare care le indică starea :',
	'info_travail_colaboratif' => 'Lucru colaborativ cu articolele',
	'info_un_article' => 'un articol,',
	'info_un_site' => 'un site,',
	'info_une_rubrique' => 'o rubrică,',
	'info_une_rubrique_02' => '1 rubrică',
	'info_url' => 'URL :',
	'info_urlref' => 'Legătură hipertext :',
	'info_utilisation_spip' => 'Puteţi începe acum să folosiţi sistemul de publicare asistată...',
	'info_visites_par_mois' => 'Afişare pe lună :',
	'info_visiteur_1' => 'Vizitator',
	'info_visiteur_2' => ' al site-ului public',
	'info_visiteurs' => 'Vizitatori',
	'info_visiteurs_02' => 'Vizitatorii site-ului public',
	'install_adresse_base_hebergeur' => 'Adresa bazei de date furnizată de provider',
	'install_echec_annonce' => 'Instalarea va eşua probabil sau va conduce la un site nefuncţional...',
	'install_extension_mbstring' => 'SPIP nu foncţionează cu :',
	'install_extension_php_obligatoire' => 'SPIP are nevoie de extensia php :',
	'install_login_base_hebergeur' => 'Login-ul de conectare furnizat de provider',
	'install_nom_base_hebergeur' => 'Numele bazei furnizată de provider :',
	'install_pas_table' => 'Bază fără tabele în acest moment',
	'install_pass_base_hebergeur' => 'Parola furnizată de provider',
	'install_php_version' => 'Versiune PHP @version@ nesatisfăcătoare (minimum = @minimum@)',
	'install_select_langue' => 'Selecţionaţi o limbă şi faceţi click pe butonul « următorul » pentru a lansa procedura de instalare.',
	'install_select_type_db' => 'Indicaţi tipul bazei de date :',
	'install_select_type_mysql' => 'MySQL',
	'install_select_type_sqlite2' => 'SQLite 2',
	'install_select_type_sqlite3' => 'SQLite 3',
	'install_serveur_hebergeur' => 'Server de bază de date atribuit de către provider',
	'install_table_prefix_hebergeur' => 'Prefix-ul tabelelor furnizat de provider :',
	'install_tables_base' => 'Tabelele bazei',
	'install_types_db_connus' => 'SPIP ştie să folosească <b>MySQL</b> (cel mai răspândit), <b>PostgreSQL</b> şi <b>SQLite</b>.', # MODIF
	'install_types_db_connus_avertissement' => 'Atenţie : mai multe plug-in-uri nu funcţionează decât cu MySQL', # MODIF
	'intem_redacteur' => 'redactor',
	'intitule_licence' => 'Licenţă',
	'item_accepter_inscriptions' => 'Acceptaţi înscrierile',
	'item_activer_messages_avertissement' => 'Activaţi mesajele de avertisment',
	'item_administrateur_2' => 'administrator',
	'item_afficher_calendrier' => 'Afişaţi în calendar',
	'item_autoriser_syndication_integrale' => 'Difuzaţi integralitatea articolelor în fişierele de sindicalizare',
	'item_choix_administrateurs' => 'administratorii',
	'item_choix_generation_miniature' => 'Generaţi în mod automat miniaturile imaginilor.',
	'item_choix_non_generation_miniature' => 'Nu generaţi miniaturile imaginilor.',
	'item_choix_redacteurs' => 'redactorii',
	'item_choix_visiteurs' => 'vizitatorii site-ului public',
	'item_creer_fichiers_authent' => 'Creaţi fişierele .htpasswd',
	'item_login' => 'Login',
	'item_messagerie_agenda' => 'Activaţi mesageria şi agenda',
	'item_mots_cles_association_articles' => 'articolelor',
	'item_mots_cles_association_rubriques' => 'rubricilor',
	'item_mots_cles_association_sites' => 'site-urilor referenţiate sau sindicalizate.',
	'item_non' => 'Nu',
	'item_non_accepter_inscriptions' => 'Nu acceptaţi înscrierile',
	'item_non_activer_messages_avertissement' => 'Fără mesaje de avertisment',
	'item_non_afficher_calendrier' => 'Nu afişaţi în calendar',
	'item_non_autoriser_syndication_integrale' => 'Difuzaţi doar un rezumat',
	'item_non_creer_fichiers_authent' => 'Nu creaţi aceste fişiere',
	'item_non_messagerie_agenda' => 'Dezactivaţi mesageria şi agenda',
	'item_non_publier_articles' => 'Nu publicaţi articolele înaintea datei de publicare fixată.',
	'item_nouvel_auteur' => 'Autor nou',
	'item_nouvelle_rubrique' => 'Rubrică nouă',
	'item_oui' => 'Da',
	'item_publier_articles' => 'Publicaţi articolele indiferent de data lor de publicare.',
	'item_reponse_article' => 'Răspuns la articolul',
	'item_visiteur' => 'vizitator',

	// J
	'jour_non_connu_nc' => 'necunoscut',

	// L
	'lien_ajouter_auteur' => 'Adăugaţi acest autor',
	'lien_email' => 'email',
	'lien_nom_site' => 'NUME SITE :',
	'lien_retirer_auteur' => 'Retrageţi autorul',
	'lien_site' => 'site',
	'lien_tout_deplier' => 'Desfăşuraţi totul',
	'lien_tout_replier' => 'Strângeţi totul',
	'lien_tout_supprimer' => 'Ştergeţi totul',
	'lien_trier_nom' => 'Triaţi după nume',
	'lien_trier_nombre_articles' => 'Triaţi după numărul articolelor',
	'lien_trier_statut' => 'Triaţi după stare',
	'lien_voir_en_ligne' => 'VEDEŢI ÎN DIRECT :',
	'logo_article' => 'VINIETA ARTICOLULUI', # MODIF
	'logo_auteur' => 'VINIETA AUTORULUI', # MODIF
	'logo_rubrique' => 'VINIETA RUBRICII', # MODIF
	'logo_site' => 'VINIETA ACESTUI SITE', # MODIF
	'logo_standard_rubrique' => 'VINIETA STANDARD A RUBRICILOR', # MODIF
	'logo_survol' => 'VINIETA PENTRU SURVOL', # MODIF

	// M
	'menu_aide_installation_choix_base' => 'Alegeţi baza dumneavoastră',
	'module_fichier_langue' => 'Fişier de limbă',
	'module_raccourci' => 'Scurtătură',
	'module_texte_affiche' => 'Text afişat',
	'module_texte_explicatif' => 'Puteţi să introduceţi scurtăturile următoare în scheletele folosite de site-ul public. Acestea vor fi traduse în mod automat în limbile pentru care există un fişier de limbă.',
	'module_texte_traduction' => 'Fişierul de limbă « @module@ » este disponibil în :',
	'mois_non_connu' => 'necunoscut',

	// O
	'onglet_contenu' => 'Conţinut',
	'onglet_declarer_une_autre_base' => 'Declaraţi o altă bază de date',
	'onglet_discuter' => 'Discutaţi',
	'onglet_interactivite' => 'Interactivitate',
	'onglet_proprietes' => 'Proprietăţi',
	'onglet_repartition_actuelle' => 'actuală',
	'onglet_sous_rubriques' => 'Sub-rubrici',

	// P
	'page_pas_proxy' => 'Această pagină nu trebuie să treacă prin proxy',
	'pas_de_proxy_pour' => 'În caz de nevoie, indicaţi maşinile sau domeniile pentru care acest proxy nu trebuie folosit (de exemplu : @exemple@)',
	'plugin_charge_paquet' => 'Încărcarea pachetului @name@',
	'plugin_erreur_charger' => 'eroare : imposibil de încărcat @zip@',
	'plugin_erreur_droit1' => 'Directorul <code>@dest@</code> nu este accesibil pentru operaţii de scriere.',
	'plugin_erreur_droit2' => 'Vă rugăm să verificaţi drepturile în acest director (şi să îl creaţi, în cazul în care nu există) sau să instalaţi fişierele prin FTP.',
	'plugin_erreur_zip' => 'eşec pclzip : eroare @status@',
	'plugin_etat_developpement' => 'în curs de dezvoltare',
	'plugin_etat_experimental' => 'experimental',
	'plugin_etat_stable' => 'stabil',
	'plugin_etat_test' => 'în test',
	'plugin_impossible_activer' => 'Imposibil de activat plugin-ul @plugin@',
	'plugin_info_automatique1' => 'Dacă vreţi să autorizaţi instalarea automată a plug-in-urilor, vă rugăm să :',
	'plugin_info_automatique2' => 'creaţi un director <code>@rep@</code> ;',
	'plugin_info_automatique3' => 'verificaţi că server-ul este autorizat să scrie în acest director.',
	'plugin_info_automatique_creer' => 'de creat în directorul rădăcină al site-ului.',
	'plugin_info_automatique_exemples' => 'exemple :',
	'plugin_info_automatique_ftp' => 'Puteţi să instalaţi plug-in-uri, prin FTP, în directorul <tt>@rep@</tt>',
	'plugin_info_automatique_lib' => 'Anumite plug-in-uri cer, de asemenea, permisiunea de a descărca fişiere în directorul <code>lib/</code> - de creat, la nevoie, în directorul rădăcină al site-ului.',
	'plugin_info_automatique_liste' => 'Listele dumneavoastră de plug-in-uri :',
	'plugin_info_automatique_liste_officielle' => 'plug-in-urile oficiale',
	'plugin_info_automatique_liste_update' => 'Aduceţi listele la zi',
	'plugin_info_automatique_ou' => 'sau...',
	'plugin_info_automatique_select' => 'Selecţionaţi mai jos un plug-in : SPIP o să îl descarce şi îl va instala în directorul <code>@rep@</code> ; dacă acest plug-in există deja, el va fi adus la zi.',
	'plugin_info_telecharger' => 'de descărcat de la @url@ şi de instalat în @rep@',
	'plugin_librairies_installees' => 'Librăriile instalate',
	'plugin_necessite_lib' => 'Acest plug-in are nevoie de librăria @lib@',
	'plugin_necessite_plugin' => 'Necesită plugin-ul @plugin@ cu versiunea @version@ minim.', # MODIF
	'plugin_necessite_spip' => 'Are nevoie de SPIP cu versiunea @version@ minim.',
	'plugin_source' => 'sursa: ',
	'plugin_titre_automatique' => 'Instalare automatică',
	'plugin_titre_automatique_ajouter' => 'Adăugaţi plug-in-uri',
	'plugin_zip_active' => 'Continuaţi pentru a-l activa',
	'plugin_zip_adresse' => 'indicaţi mai jos adresa unui fişier zip conţinând plug-in-ul de descărcat, sau chiar adresa unei liste de plug-in-uri.',
	'plugin_zip_adresse_champ' => 'Adresa plug-uluiin sau a listei ',
	'plugin_zip_content' => 'Conţine fişierele următoare(@taille@),<br />gata de instalare în directorul <code>@rep@</code>',
	'plugin_zip_installe_finie' => 'Fişierul @zip@ a fost decomprimat şi instalat.',
	'plugin_zip_installe_rep_finie' => 'Fişierul @zip@ a fost decomprimat şi instalat în directorul @rep@',
	'plugin_zip_installer' => 'Puteţi acum să îl instalaţi.',
	'plugin_zip_telecharge' => 'Fişierul @zip@ a fost descărcat',
	'plugins_actifs' => '@count@ plug-in-uri activate.',
	'plugins_compte' => '@count@ plug-in-uri',
	'plugins_disponibles' => '@count@ plug-in-uri disponibile.',
	'plugins_erreur' => 'Eroare în plug-in-urile : @plugins@',
	'plugins_liste' => 'Lista plugin-urilor',
	'plugins_vue_hierarchie' => 'Ierarhie',
	'plugins_vue_liste' => 'Listă',
	'protocole_ldap' => 'Versiunea protocolului :',

	// R
	'repertoire_plugins' => 'Director :',
	'required' => '[Obligatorie]', # MODIF

	// S
	'sans_heure' => 'fără oră',
	'statut_admin_restreint' => '(administrator cu drepturi restrânse)', # MODIF

	// T
	'taille_cache_image' => 'Imaginile calculate automat de către SPIP (viniete de documente, titluri prezentate sub formă grafică, funcţii matematice în format TeX...) ocupă în directorul @dir@ un total de @taille@.',
	'taille_cache_infinie' => 'Acest site nu prevede limitarea mărimii directorului <code>CACHE/</code>.',
	'taille_cache_maxi' => 'SPIP încearcă să limiteze mărimea directorului <code>CACHE/</code> al acestui site la aproximativ <b>@octets@</b> octeţi de date.',
	'taille_cache_octets' => 'Mărimea tamponului este acum de @octets@.', # MODIF
	'taille_cache_vide' => 'Tamponul este gol.',
	'taille_repertoire_cache' => 'Mărimea directorului de tampon',
	'text_article_propose_publication' => 'Articol propus pentru publicare. ',
	'texte_acces_ldap_anonyme_1' => 'Anumite server-e LDAP nu acceptă accesul anonim. În acest caz va trebui să specificaţi un identificator de acces iniţial pentru a putea recupera datele din anuar. În majoritatea cazurilor, însă, aceste câmpuri pot fi lăsate goale.',
	'texte_admin_effacer_01' => 'Această comandă şterge <i>tot</i> conţinutul bazei de date,
incluzând <i>toate</i> informaţiile referitoare la redactori sau administratori. După execuţia acestei comenzi va trebui să relansaţi procedura de
reinstalare a SPIP pentru a recrea o nouă bază de date cât şi un nou acces administrator.',
	'texte_adresse_annuaire_1' => '(Dacă anuarul este instalat pe aceeaşi maşină ca şi site-ul Web, este vorba probabil de «localhost».)',
	'texte_ajout_auteur' => 'Autorul următor a fost adăugat la articol :',
	'texte_annuaire_ldap_1' => 'Dacă avezi un acces la un anuar LDAP, puteţi să îl folosiţi pentru a importa în mod automat utilizatorii SPIP.',
	'texte_article_statut' => 'Acest articol este :',
	'texte_article_virtuel' => 'Articol virtual',
	'texte_article_virtuel_reference' => '<b>Articol virtual :</b> articol referenţiat pe site-ul dumneavoastră SPIP, dar redirijat către un alt URL. Pentru a şterge redirijarea, ştergeţi URL-ul.',
	'texte_aucun_resultat_auteur' => 'Nici un rezultat pentru "@cherche_auteur@"',
	'texte_auteur_messagerie' => 'Acest site vă poate indica în permanenţă lista redactorilor conectaţi, ceea ce vă permite schimbul de mesaje în direct. Puteţi decide să nu apăreţi în această listă (sunteţi « invizibil » pentru ceilalţi utilizatori).',
	'texte_auteurs' => 'AUTORII',
	'texte_choix_base_1' => 'Alegeţi baza dumneavoastră :',
	'texte_choix_base_2' => 'Server-ul SQL conţine mai multe baze de date.',
	'texte_choix_base_3' => '<b>Selecţionaţi</b> aici aceea care v-a fost atribuită de către furnizorul dumneavoastră de internet:',
	'texte_choix_table_prefix' => 'Prefixul tabelelor :',
	'texte_compte_element' => '@count@ element(e)',
	'texte_compte_elements' => '@count@ element(e)',
	'texte_conflit_edition_correction' => 'Vă rugăm să controlaţi mai jos diferenţele între cele două versiuni ale textului; puteţi de asemenea să copiaţi modificările dumneavoastră, pentru a reîncepe.',
	'texte_connexion_mysql' => 'Vă rugăm să consultaţi informaţiile care v-au fost date de către furnizorul dumneavoastră : ar trebui să găsiţi codurile de acces la server-ul de baze de date.',
	'texte_contenu_article' => '(Conţinutul articolului în câteva cuvinte.)',
	'texte_contenu_articles' => 'În funcţie de formatul ales pentru site-ul dumneavoastră, puteţi decide
   că anumite elemente ale articolelor nu sunt folosite.
   Indicaţi lista de mai jos pentru a indica care elemente vor fi disponibile.',
	'texte_crash_base' => 'Dacă baza dumneavoastră de date a suferit o cădere,
   puteţi încerca o reparare automată.',
	'texte_creer_rubrique' => 'Înainte de a putea scrie articole,<br />   trebuie să creaţi o rubrică.',
	'texte_date_creation_article' => 'DATA CREĂRII ARTICOLULUI :',
	'texte_date_publication_anterieure' => 'DATA REDACTĂRII ANTERIOARE :',
	'texte_date_publication_anterieure_nonaffichee' => 'Nu afişaţi data redactării anterioare.',
	'texte_date_publication_article' => 'DATA PUBLICĂRII ÎN LINIE :',
	'texte_descriptif_rapide' => 'Descriere pe scurt',
	'texte_effacer_base' => 'Ştergeţi baza de date SPIP',
	'texte_effacer_statistiques' => 'Ştergeţi statisticile',
	'texte_en_cours_validation' => 'Articolele şi ştirile de mai jos sunt propuse pentru publicare.', # MODIF
	'texte_enrichir_mise_a_jour' => 'Puteţi îmbogăţi aranjarea în pagină a textului dumneavoastră prin folosirea « scurtăturilor tipografice ».',
	'texte_fichier_authent' => '<b>Trebuie ca SPIP să creeze fişierele speciale <tt>.htpasswd</tt>
  şi <tt>.htpasswd-admin</tt> în directorul @dossier@ ?</b>
  Aceste fişiere vă pot servi pentru a restânge accesul autorilor şi administratorilor în alte locuri ale site-ului dumneavoastră
  (programe externe de statistici, de exemplu).
  Dacă nu vedeţi utilitatea unui astfel de mecanism de protecţie, puteţi lăsa această opţiune
  la valoare ei implicită (fără crearea de fişiere).', # MODIF
	'texte_informations_personnelles_1' => 'Sistemul vă va crea acum un acces personalizat la site.',
	'texte_informations_personnelles_2' => '(Notă : dacă este vorba de o reinstalare, şi dacă accesul dumneavoastră merge încă, puteţi', # MODIF
	'texte_introductif_article' => '(Text introductiv al articolului.)',
	'texte_jeu_caractere' => 'Este recomandabil să folosiţi, pentru site-ul dumneavoastră, alfabetul universal (<tt>utf-8</tt>) : acesta permite afişarea textelor în toate limbile şi nu pune probleme de compatibilitate navigatoarelor moderne.',
	'texte_jeu_caractere_3' => 'Site-ul dumneavoastră este, actualmente, configurat să folosească codarea:',
	'texte_jeu_caractere_4' => 'Dacă această setare nu corespunde realităţii datelor dumneavoastră (de exemplu ca urmare a unei restaurări a bazei de date) sau dacă tocmai demaraţi acest site şi doriţi să porniţi cu o altă codare, specificaţi aici alegerea dumneavoastră :',
	'texte_login_ldap_1' => '(Lăsaţi gol pentru un acces anonim, sau introduceţi o cale completă, de exemplu: « <tt>uid=ionescu, ou=utilizatori, dc=domeniul-meu, dc=ro</tt> ».)',
	'texte_login_precaution' => 'Atenţie ! Acesta este login-ul cu care sunteţi conectat acum.
 Utilizaţi acest formular cu precauţie...',
	'texte_messagerie_agenda' => 'O mesagerie permite redactorilor site-ului să comunice între ei direct în spaţiul privat al site-ului. O mesagerie este asociată unei agende.',
	'texte_mise_a_niveau_base_1' => 'Tocmai aţi adus la zi fişierele SPIP.
 Trebuie ca acum să aduceţi la zi şi baza de date a site-ului.',
	'texte_modifier_article' => 'Modificaţi articolul :',
	'texte_multilinguisme' => 'Dacă doriţi să gestionaţi articole în mai multe limbi, cu o navigare complexă, puteţi să adăugaţi un meniu de selectare a limbii pentru articole şi/sau rubrici, în funcţie de organizarea site-ului dumneavoastră.', # MODIF
	'texte_multilinguisme_trad' => 'Puteţi, de asemenea, să activaţi sistemul de gestiune a legăturilor între diferitele traduceri ale unui articol.', # MODIF
	'texte_non_compresse' => '<i>necomprimat</i> (server-ul dumneavoastră nu suportă această funcţionalitate)',
	'texte_nouvelle_version_spip_1' => 'Aţi instalat o nouă versiune SPIP.',
	'texte_nouvelle_version_spip_2' => 'Această nouă versiune necesită o aducere la zi mai completă decât în mod obişnuit. Dacă sunteţi webmaster-ul site-ului, vă rugam să ştergeţi fişierul @connect@ şi să reluaţi instalarea de la capăt pentru a permite aducerea la zi a parametrilor dumneavoastră de conectare la baza de date.
(Nota Bene : dacă cumva aţi uitat parametrii de conectare, aruncaţi o privire la fişierul @connect@ înainte de a-l şterge...)', # MODIF
	'texte_operation_echec' => 'Întoarceţi-vă la pagina anterioară, selecţionazi o altă bază de date sau creaţi una nouă. Verificaţi informaţiile date de furnizorul dumneavoastră de hosting.',
	'texte_plus_trois_car' => 'mai mult de 3 caractere',
	'texte_plusieurs_articles' => 'Mai multe articole găsite pentru "@cherche_auteur@":',
	'texte_port_annuaire' => '(Valoarea implicită este în general cea bună.)',
	'texte_presente_plugin' => 'Această pagină conţine lista plugin-urilor disponibile pentru acest site. Puteţi să activaţi plugin-urile necesare bifând căsuţa corespunzătoare.',
	'texte_proposer_publication' => 'Când articolul dumneavoastră este terminat,<br />puteţi să-l propuneţi pentru publicare.',
	'texte_proxy' => 'În anumite cazuri (intranet, reţea protejată, ş.a.m.d.), site-urile distante (documentaţia SPIP, site-uri sindicalizate, etc.) nu pot fi accesibile decât print-run <i>proxy HTTP</i>. Vă rugăm să indicaţi mai jos adresa proxy-ului sub forma @proxy_en_cours@. În general, puteţi lăsa acest câmp gol.',
	'texte_publication_articles_post_dates' => 'Ce comportament trebuie să adopte SPIP în ceea ce priveşte articolele
 a căror dată de publicare a fost fixată în viitor ?',
	'texte_rappel_selection_champs' => '[Nu uitaţi să selecţionaţi corect acest câmp.]',
	'texte_recalcul_page' => 'Dacă doriţi recalcularea unei singure pagini
 treceţi mai degrabă în spaţiul public şi utilizaţi butonul « recalculează ».',
	'texte_recuperer_base' => 'Reparaţi baza de date',
	'texte_reference_mais_redirige' => 'articol referenţiat în site-ul dumneavoastră, dar redirijat către un alt URL.',
	'texte_requetes_echouent' => '<b>Atunci când anumite cereri SQL eşuează în mod sistematic şi fără un motiv evident, este posibil ca baza de date însăşi să fie cauza.</b>
Server-ul dumneavoastră SQL dispune de o capacitate de reparare a tabelelor sale atunci când acestea s-au stricat în mod accidental.
Puteţi încerca aici această reparare ; în caz de eşec, conservaţi o copie de ecran, care poate că conţine indicii referitor la ceea ce nu merge...
Dacă problema persistă, vă rugăm să-l contactaţi pe furnizorul dumneavoastră de hosting.', # MODIF
	'texte_selection_langue_principale' => 'Puteţi să selecţionaţi aici « limba principală » a site-ului. Această alegere nu vă obligă - din fericire ! - să scrieţi articolele în limba selecţionată, dar permite determinarea :
 <ul><li> formatul implicit al afişării datelor pe site-ul public;</li>
 <li> natura motorului tipografic pe care SPIP îl foloseşte pentru afişarea site-ului public;</li>
 <li> limba folosită în formularele site-ului public;</li>
 <li> limba implicită în spaţiul privat.</li></ul>',
	'texte_sous_titre' => 'Sub-titlu',
	'texte_statistiques_visites' => '(barele întunecate :  duminicile / curba întunecată : evoluţia mediei)',
	'texte_statut_attente_validation' => 'în aşteptarea validării',
	'texte_statut_publies' => 'publicate în direct',
	'texte_statut_refuses' => 'refuzate',
	'texte_suppression_fichiers' => 'Utilizaţi această comandă pentru a şterge toate fişierele prezente în tamponul SPIP. Aceasta permite, de exemplu, forţarea unui recalcul al tuturor paginilor dacă aţi făcut modificări importante de grafică sau structură a site-ului
avez fait des modifications importantes de graphisme ou de structure du site.',
	'texte_sur_titre' => 'Supra-titlu',
	'texte_table_ok' => ': această tabelă este OK.',
	'texte_tentative_recuperation' => 'Tentativă de recuperare',
	'texte_tenter_reparation' => 'Încercaţi o reparare a bazei de date',
	'texte_test_proxy' => 'Pentru a încerca acest proxy, indicaţi aici adresa unui site Web
 pe care doriţi să-l testaţi.',
	'texte_titre_02' => 'Titlu :',
	'texte_titre_obligatoire' => '<b>Titlu</b> [Obligatoriu]',
	'texte_travail_article' => '@nom_auteur_modif@ a lucrat pe acest articol acum @date_diff@ minute',
	'texte_travail_collaboratif' => 'Dacă este frecvent ca mai mulţi redactori
  să muncească pe acelaşi articol, sistemul
  poate afişa articolele « deschise » recent
  pentru a evita modificări simultane ale aceluiaşi articol.
  Această opţiune este dezactivată în mod implicit
  pentru a evita afişarea de mesaje intempensive de avertisment.',
	'texte_vide' => 'gol',
	'texte_vider_cache' => 'Goliţi tamponul',
	'titre_admin_tech' => 'Întreţinere tehnică',
	'titre_admin_vider' => 'Întreţinere tehnică',
	'titre_cadre_afficher_article' => 'Afişaţi articolele',
	'titre_cadre_afficher_traductions' => 'Afişaţi starea traducerilor pentru limbile următoare :',
	'titre_cadre_ajouter_auteur' => 'ADĂUGAŢI UN AUTOR :',
	'titre_cadre_interieur_rubrique' => 'În interiorul rubricii',
	'titre_cadre_numero_auteur' => 'AUTOR NUMĂRUL',
	'titre_cadre_signature_obligatoire' => '<b>Semnătura</b> [Obligatorie]
',
	'titre_config_contenu_notifications' => 'Notificări',
	'titre_config_contenu_prive' => 'În spaţiul privat',
	'titre_config_contenu_public' => 'Pe site-ul public',
	'titre_config_fonctions' => 'Configuraţia site-ului',
	'titre_configuration' => 'Configuraţia site-ului',
	'titre_conflit_edition' => 'Conflict în timpul editării',
	'titre_connexion_ldap' => 'Opţiuni : <b>Conexiunea dumneavoastră LDAP</b>',
	'titre_groupe_mots' => 'GRUP DE CUVINTE :',
	'titre_langue_article' => 'LIMBA ARTICOLULUI', # MODIF
	'titre_langue_rubrique' => 'LIMBA RUBRICII', # MODIF
	'titre_langue_trad_article' => 'LIMBA ŞI TRADUCERILE ARTICOLULUI',
	'titre_les_articles' => 'ARTICOLELE',
	'titre_messagerie_agenda' => 'Mesagerie şi agendă',
	'titre_naviguer_dans_le_site' => 'Navigaţi în structura site-ului...',
	'titre_nouvelle_rubrique' => 'Rubrică nouă',
	'titre_numero_rubrique' => 'RUBRICA NUMĂRUL :',
	'titre_page_articles_edit' => 'Modificaţi : @titre@',
	'titre_page_articles_page' => 'Articolele',
	'titre_page_articles_tous' => 'Tot site-ul',
	'titre_page_calendrier' => 'Calendar @nom_mois@ @annee@',
	'titre_page_config_contenu' => 'Configuraţia site-ului',
	'titre_page_delete_all' => 'ştergere totală şi ireversibilă',
	'titre_page_recherche' => 'Rezultatele căutării @recherche@',
	'titre_page_statistiques_referers' => 'Statistici (legături în intrare)',
	'titre_page_upgrade' => 'Actualizaţi SPIP',
	'titre_publication_articles_post_dates' => 'Publicarea articolelor post-datate',
	'titre_reparation' => 'Reparare',
	'titre_suivi_petition' => 'Urmărirea petiţiilor',
	'tls_ldap' => 'Transport Layer Security :',
	'trad_article_traduction' => 'Toate versiunile acestui articol :',
	'trad_delier' => 'Nu mai legaţi articolul de aceste traduceri', # MODIF
	'trad_lier' => 'Acest articol este o traducere a articolului cu numărul :',
	'trad_new' => 'Scrieţi o nouă traducere a acestui articol', # MODIF

	// U
	'utf8_convert_erreur_orig' => 'Eroare : codarea @charset@ nu este suportată.',

	// V
	'version' => 'Versiune :'
);
